@@ -6,7 +6,6 @@ mod tokio_util;
 mod unstable_checker;
 
 pub use data_channel::*;
-use deno_core::error::AnyError;
 pub use fs_util::*;
 pub use loader::*;
 pub use store::*;
@@ -14,9 +13,10 @@ pub use tokio_util::*;
 pub use unstable_checker::*;
 
 use async_trait::async_trait;
-
+use deno_core::error::AnyError;
+use std::fmt;
 #[async_trait]
-pub trait ModuleStore: Send + Sync {
+pub trait ModuleStore: fmt::Debug + Send + Sync {
     async fn get(&self, specifier: &str) -> Result<String, AnyError>;
     async fn put(&self, specifier: String, code: String) -> Result<(), AnyError>;
 }
